#
# spec file for package gnutls
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define gnutls_sover 28
%define gnutlsxx_sover 28
%define gnutls_ossl_sover 27

Name:           gnutls
Version:        3.2.15
Release:        9.1
Summary:        The GNU Transport Layer Security Library
License:        LGPL-2.1+ and GPL-3.0+
Group:          Productivity/Networking/Security
Url:            http://www.gnutls.org/
Source0:        ftp://ftp.gnutls.org/gcrypt/gnutls/v3.2/%{name}-%{version}.tar.xz
# signature is checked by source services.
Source1:        ftp://ftp.gnutls.org/gcrypt/gnutls/v3.2/%{name}-%{version}.tar.xz.sig
Source2:        %name.keyring
Source3:        baselibs.conf

# PATCH-FIX-OPENSUSE gnutls-3.0.26-skip-test-fwrite.patch andreas.stieger@gmx.de -- skip a failing test
Patch3:         gnutls-3.0.26-skip-test-fwrite.patch

# PATCH-OPENSUSE gnutls-implement-trust-store-dir-3.2.10.diff allow to point to /etc/ssl/certs as trust
Patch6:         gnutls-implement-trust-store-dir-3.2.10.diff

# PATCH-UPSTREAM gnutls-CVE-2014-8564.patch bnc#904603
Patch7:         gnutls-CVE-2014-8564.patch
Patch8:         gnutls-CVE-2015-0294.patch
Patch9:         gnutls-GNUTLS-SA-2015-2.patch
Patch10:        gnutls-CVE-2015-3622.patch
Patch11:        gnutls-CVE-2015-6251.patch
Patch12:        gnutls-CVE-2016-7444.patch
Patch13:        gnutls-CVE-2016-8610.patch
Patch14:        gnutls-CVE-2017-5335.patch
Patch15:        gnutls-CVE-2017-5336.patch
Patch16:        gnutls-CVE-2017-5337.patch
Patch17:        0001-Do-not-infinite-loop-if-an-EOF-occurs-while-skipping.patch

BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libidn-devel
BuildRequires:  libnettle-devel >= 2.7
BuildRequires:  libtasn1-devel >= 2.14
BuildRequires:  libtool
%ifarch %ix86 x86_64 ppc ppc64 s390x armv7l armv7hl
BuildRequires:  valgrind
%endif
%if %suse_version >= 1230
BuildRequires:  makeinfo
%endif
BuildRequires:  p11-kit-devel >= 0.11
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      gnutls-64bit
%endif

%description
The GnuTLS project aims to develop a library that provides a secure
layer over a reliable transport layer. Currently the GnuTLS library
implements the proposed standards of the IETF's TLS working group.

%package -n libgnutls%{gnutls_sover}
Summary:        The GNU Transport Layer Security Library
License:        LGPL-2.1+
Group:          Productivity/Networking/Security

%description -n libgnutls%{gnutls_sover}
The GnuTLS project aims to develop a library that provides a secure
layer over a reliable transport layer. Currently the GnuTLS library
implements the proposed standards of the IETF's TLS working group.

%package -n libgnutlsxx%{gnutlsxx_sover}
Summary:        The GNU Transport Layer Security Library
License:        LGPL-2.1+
Group:          Productivity/Networking/Security

%description -n libgnutlsxx%{gnutlsxx_sover}
The GnuTLS project aims to develop a library that provides a secure
layer over a reliable transport layer. Currently the GnuTLS library
implements the proposed standards of the IETF's TLS working group.


%package -n libgnutls-openssl%{gnutls_ossl_sover}
Summary:        The GNU Transport Layer Security Library
License:        GPL-3.0+
Group:          Productivity/Networking/Security

%description -n libgnutls-openssl%{gnutls_ossl_sover}
The GnuTLS project aims to develop a library that provides a secure
layer over a reliable transport layer. Currently the GnuTLS library
implements the proposed standards of the IETF's TLS working group.


%package -n libgnutls-devel
Summary:        Development package for gnutls
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
PreReq:         %install_info_prereq
Requires:       glibc-devel
Requires:       libgnutls%{gnutls_sover} = %{version}
Provides:       gnutls-devel = %{version}-%{release}

%description -n libgnutls-devel
Files needed for software development using gnutls.

%package -n libgnutlsxx-devel
Summary:        Development package for gnutls
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
PreReq:         %install_info_prereq
Requires:       libgnutls-devel = %{version}
Requires:       libgnutlsxx%{gnutlsxx_sover} = %{version}
Requires:       libstdc++-devel

%description -n libgnutlsxx-devel
Files needed for software development using gnutls.


%package -n libgnutls-openssl-devel
Summary:        Development package for gnutls
License:        GPL-3.0+
Group:          Development/Libraries/C and C++
Requires:       libgnutls-devel = %{version}
Requires:       libgnutls-openssl%{gnutls_ossl_sover} = %{version}

%description -n libgnutls-openssl-devel
Files needed for software development using gnutls.


%prep
%setup -q
%patch3
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1

%build
autoreconf -if
%configure \
        gl_cv_func_printf_directive_n=yes \
        gl_cv_func_printf_infinite_long_double=yes \
        --disable-static \
        --with-pic \
        --disable-rpath \
        --disable-silent-rules \
	--with-default-trust-store-dir=/var/lib/ca-certificates/pem \
	--disable-srp \
        --with-sysroot=/%{?_sysroot}
%__make %{?_smp_mflags}

%install
%make_install
rm -rf %{buildroot}%{_datadir}/locale/en@{,bold}quot
# Do not package static libs and libtool files
rm -f %{buildroot}%{_libdir}/*.la

# install docs
%__mkdir -p %{buildroot}%{_docdir}/libgnutls-devel/
%__cp doc/gnutls.html doc/*.png doc/gnutls.pdf %{buildroot}%{_docdir}/libgnutls-devel/
%__mkdir -p %{buildroot}%{_docdir}/libgnutls-devel/reference
%__cp doc/reference/html/* %{buildroot}%{_docdir}/libgnutls-devel/reference/
%__mkdir -p %{buildroot}%{_docdir}/libgnutls-devel/examples
%__cp doc/examples/*.{c,h} %{buildroot}%{_docdir}/libgnutls-devel/examples/

%find_lang libgnutls --all-name

%check
%if ! 0%{?qemu_user_space_build}
%__make check
%endif

%clean
rm -rf %{buildroot}

%post -n libgnutls%{gnutls_sover} -p /sbin/ldconfig

%postun -n libgnutls%{gnutls_sover} -p /sbin/ldconfig

%post -n libgnutlsxx%{gnutlsxx_sover} -p /sbin/ldconfig

%postun -n libgnutlsxx%{gnutlsxx_sover} -p /sbin/ldconfig

%post -n libgnutls-openssl%{gnutls_ossl_sover} -p /sbin/ldconfig

%postun -n libgnutls-openssl%{gnutls_ossl_sover} -p /sbin/ldconfig

%post -n libgnutls-devel
%install_info --info-dir=%{_infodir} %{_infodir}/gnutls.info.gz

%postun -n libgnutls-devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gnutls.info.gz

%files -f libgnutls.lang
%defattr(-, root, root)
%doc THANKS README NEWS ChangeLog COPYING COPYING.LESSER AUTHORS doc/TODO
%{_bindir}/certtool
%{_bindir}/crywrap
%{_bindir}/gnutls-cli
%{_bindir}/gnutls-cli-debug
%{_bindir}/gnutls-serv
%{_bindir}/ocsptool
%{_bindir}/psktool
%{_bindir}/p11tool
%{_bindir}/srptool
%{_bindir}/danetool
%{_mandir}/man1/*

%files -n libgnutls%{gnutls_sover}
%defattr(-,root,root)
%{_libdir}/libgnutls.so.%{gnutls_sover}*
%{_libdir}/libgnutls-xssl.so.*

%files -n libgnutls-openssl%{gnutls_ossl_sover}
%defattr(-,root,root)
%{_libdir}/libgnutls-openssl.so.%{gnutls_ossl_sover}*

%files -n libgnutlsxx%{gnutlsxx_sover}
%defattr(-,root,root)
%{_libdir}/libgnutlsxx.so.%{gnutlsxx_sover}*

%files -n libgnutls-devel
%defattr(-, root, root)
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/abstract.h
%{_includedir}/%{name}/crypto.h
%{_includedir}/%{name}/compat.h
%{_includedir}/%{name}/dtls.h
%{_includedir}/%{name}/gnutls.h
%{_includedir}/%{name}/openpgp.h
%{_includedir}/%{name}/ocsp.h
%{_includedir}/%{name}/pkcs11.h
%{_includedir}/%{name}/pkcs12.h
%{_includedir}/%{name}/x509.h
%{_includedir}/%{name}/tpm.h
%{_includedir}/%{name}/xssl.h
%{_libdir}/libgnutls.so
%{_libdir}/libgnutls-xssl.so
%{_libdir}/pkgconfig/gnutls.pc
%{_mandir}/man3/*
%{_infodir}/*.*
%doc %{_docdir}/libgnutls-devel

%files -n libgnutlsxx-devel
%defattr(-, root, root)
%{_libdir}/libgnutlsxx.so
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/gnutlsxx.h

%files -n libgnutls-openssl-devel
%defattr(-, root, root)
%{_libdir}/libgnutls-openssl.so
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/openssl.h

%changelog
* Tue Jan 24 2017 vcizek@suse.com
- Fix an infinite loop if an EOF occurs while skipping a PGP packet
  * add 0001-Do-not-infinite-loop-if-an-EOF-occurs-while-skipping.patch
* Tue Jan 10 2017 vcizek@suse.com
- GNUTLS-SA-2017-2 (bsc#1018832)
  * several memory corruptions in OpenPGP certificate decoding
  * added patches:
    gnutls-CVE-2017-5335.patch
    gnutls-CVE-2017-5337.patch
    gnutls-CVE-2017-5336.patch
- GNUTLS-SA-2016-3 (bsc#999646)
  * Incorrect certificate validation when using OCSP responses
  * added gnutls-CVE-2016-7444.patch
- remote denial of service in SSL alert handling (bsc#1005879)
  * added gnutls-CVE-2016-8610.patch
* Fri Aug 21 2015 vcizek@suse.com
- fix for CVE-2015-6251 (GNUTLS-SA-2015-3) (bsc#941794)
  * double free in certificate DN decoding
  * added gnutls-CVE-2015-6251.patch
* Mon Aug  3 2015 vcizek@suse.com
- fix for CVE-2015-3622 in bundled libtasn1 (bsc#929414)
  * invalid read in octet string
  * added gnutls-CVE-2015-3622.patch
- fix for GNUTLS-SA-2015-2 (bsc#929690)
  * ServerKeyExchange signature issue
  * added gnutls-GNUTLS-SA-2015-2.patch
* Wed Mar 18 2015 vcizek@suse.com
- fix for CVE-2015-0294 (bnc#919938)
  * certificate algorithm consistency checking issue
  * added gnutls-CVE-2015-0294.patch
* Wed Nov 12 2014 meissner@suse.com
- gnutls-CVE-2014-8564.patch: Fixed parsing problem in elliptic
  curve blobs over TLS that could lead to remote crashes.
  (bnc#904603 CVE-2014-8564)
* Tue Jun  3 2014 meissner@suse.com
- Version 3.2.15 (released 2014-05-30)
  * * libgnutls: Eliminated memory corruption issue in Server Hello parsing.
  Issue reported by Joonas Kuorilehto of Codenomicon. (CVE-2014-3466 / bnc#880730)
  * * libgnutls: Several memory leaks caused by error conditions were
  fixed. The leaks were identified using valgrind and the Codenomicon
  TLS test suite.
  * * libgnutls: Increased the maximum certificate size buffer
  in the PKCS #11 subsystem.
  * * libgnutls: Check the return code of getpwuid_r() instead of relying
  on the result value. That avoids issue in certain systems, when using
  tofu authentication and the home path cannot be determined. Issue reported
  by Viktor Dukhovni.
  * * gnutls-cli: if dane is requested but not PKIX verification, then
  only do verify the end certificate.
  * * ocsptool: Include path in ocsp request. This resolves #108582
  (https://savannah.gnu.org/support/?108582), reported by Matt McCutchen.
- Version 3.2.14 (released 2014-05-06)
  * * libgnutls: Fixed issue with the check of incoming data when two
  different recv and send pointers have been specified. Reported and
  investigated by JMRecio.
  * * libgnutls: Fixed issue in the RSA-PSK key exchange, which would
  result to illegal memory access if a server hint was provided.
  * * libgnutls: Fixed client memory leak in the PSK key exchange, if a
  server hint was provided.
  * * libgnutls: Several small bug fixes identified using valgrind and
  the Codenomicon TLS test suite.
  * * libgnutls: Several small bug fixes found by coverity.
  * * libgnutls-dane: Accept a certificate using DANE if there is at least one
  entry that matches the certificate. Patch by simon [at] arlott.org.
  * * configure: Added --with-nettle-mini option, which allows linking
  with a libnettle that contains gmp.
  * * certtool: The ECDSA keys generated by default use the SECP256R1 curve
  which is supported more widely than the previously used SECP224R1.
- CVE-2014-3466.patch: is upstream.
* Mon Jun  2 2014 shchang@suse.com
- Fixed bug[ bnc#880730],  CVE-2014-3466: gnutls: Possible memory corruption during connect
  Add patch file: CVE-2014-3466.patch
* Tue Apr  8 2014 shchang@suse.com
- Upgrade to 3.2.13
  * Version 3.2.13 (released 2014-04-07)
  * * libgnutls: gnutls_openpgp_keyring_import will no longer fail silently
  if there are no base64 data. Report and patch by Ramkumar Chinchani.
  * * libgnutls: gnutls_record_send is now safe to be called under DTLS when
  in corked mode.
  * * libgnutls: Ciphersuites that use the SHA256 or SHA384 MACs are
  only available in TLS 1.0 as SSL 3.0 doesn't specify parameters for
  these algorithms.
  * * libgnutls: Changed the behaviour in wildcard acceptance in certificates.
  Wildcards are only accepted when there are more than two domain components
  after the wildcard. This drops support for the permissive RFC2818 wildcards
  and adds more conservative support based on the suggestions in RFC6125. Suggested
  by Jeffrey Walton.
  * * certtool: When no password is provided to export a PKCS #8 keys, do
  not encrypt by default. This reverts to the certtool behavior of gnutls
  3.0. The previous behavior of encrypting using an empty password can be
  replicating using the new parameter --empty-password.
  * * p11tool: Avoid dual initialization of the PKCS #11 subsystem when
  the --provider option is given.
  * * API and ABI modifications:
  No changes since last version.
  Add files: gnutls-3.2.13.tar.xz, gnutls-3.2.13.tar.xz.sig
  delete files: CVE-2014-0092.patch, gnutls-3.2.11.tar.xz, gnutls-3.2.11.tar.xz.sig
* Mon Mar  3 2014 shchang@suse.com
- Fixed bug [ bnc#865804] gnutls: CVE-2014-0092, insufficient X.509 certificate verification
  Add patch file: CVE-2014-0092.patch
* Thu Feb 13 2014 meissner@suse.com
- Upgraded to 3.2.11
  * * libgnutls: Tolerate servers that send the SUPPORTED ECC extension.
  * * libgnutls: Reduced the TLS and DTLS version requirements for all
    ciphersuites that are not GCM.
  * * libgnutls: When two initial keywords are specified then treat the
    second as having the '+' modifier.
  * * libgnutls:  When using a PKCS #11 module for verification ensure that
    it has been marked a trusted policy module in p11-kit. Moreover, when an
    empty (i.e., "pkcs11:") URL is specified, then try all trusted modules
    in the system for verification.
    http://p11-glue.freedesktop.org/doc/p11-kit/pkcs11-conf.html
  * * libgnutls: Fixed bug that prevented the rejection of v1 intermediate
    CA certificates. Reported and investigated by Suman Jana.
    CVE-2014-1959 / bnc#863989
  * * certtool: Added the --ask-pass option.
- gnutls-3.2.10-supported-ecc.patch: upstreamed
- gnutls-fix-missing-ipv6.patch: upstreamed
* Tue Feb 11 2014 meissner@suse.com
- Upgrade to 3.2.10 (released 2014-01-31)
  * * libgnutls: fixed null pointer derefence when printing a certificate
    DN and an LDAP description isn't present.
  * * libgnutls: gnutls_db_check_entry_time will correctly report the time;
    report and patch by Jonathan Roudiere.
- Upgrade to 3.2.9 (released 2014-01-24)
  * * libgnutls: The %%DUMBFW option in priority string only
    appends data to client hello if the expected size is in the
    "black hole" range.
  * * libgnutls: %%COMPAT implies %%DUMBFW.
  * * libgnutls: gnutls_session_get_desc() returns a more compact
    ciphersuite description.
  * libgnutls: In PKCS #11 allow deleting multiple non-certificate data.
  * * libgnutls: When a PKCS #11 trust store is specified (e.g. using the
    configure option --with-default-trust-store-pkcs11), then the PKCS #11
    token is used on demand to obtain the trusted anchors, rather than
    preloading all trusted certificates. That delegates CA certificate
    management and blacklist checking to the PKCS #11 module.
  * * libgnutls: When a PKCS #11 trust store is specified in configure
    option or in gnutls_x509_trust_list_add_trust_file(), then the module is
    used to obtain the verification anchors and any required blacklists as
    in
    http://p11-glue.freedesktop.org/doc/storing-trust-policy/storing-trust-pkcs11.html
  * * libgnutls: Fix in OCSP certificate status extension handling
    in non-blocking servers. Patch by Nils Maier.
  * * p11tool: Added --so-login option to force login as security
    officer (admin).
- reenable ECDHE after review of modern cryptographic practices.
- gnutls-fix-missing-ipv6.patch: fixed getaddrinfo() / socket protocol
  mismatch in gnutls-serv
- gnutls-3.2.10-supported-ecc.patch: if the server reports ECC supported
  curves, do not abort. (e.g. www.bsi.de does that)
* Sat Dec 21 2013 shchang@suse.com
- Upgrade to 3.2.8
  * Version 3.2.8 (released 2013-12-20)
  * * libgnutls: Updated code for AES-NI. That prevents an uninitialized
  variable complaint from valgrind.
  * * libgnutls: Enforce a maximum size for DH primes.
  * * libgnutls: Added SSSE3 optimized SHA1, and SHA256, using Andy
  Polyakov's code.
  * * libgnutls: Added SSSE3 optimized AES using Mike Hamburg's code.
  * * libgnutls: It only links to librt if the required functions are not
  present in libc. This also prevents an indirect linking to libpthread.
  * * libgnutls: Fixed issue with gnulib strerror replacement by adding
  the strerror gnulib module.
  * * libgnutls: The time provided in the TLS random values is only
  precise on its first 3 bytes. That prevents leakage of the precise
  system time (at least on the client side when only few connections are
  done on a single server).
  * * certtool: The --verify option will use the system CAs if the
  load-ca-certificate option is not provided.
  * * configure: Added option --with-default-blacklist-file to allow
  specifying a certificate blacklist file.
  * * configure: Added --disable-non-suiteb-curves option. This option
  restricts the supported curves to SuiteB curves.
  * * API and ABI modifications: gnutls_record_check_corked: Added
  Add files: gnutls-3.2.8.tar.xz, gnutls-3.2.8.tar.xz.sig, gnutls-implement-trust-store-dir-3.2.8.diff,
  gnutls-3.2.8-noecc.patch
  Delete files: gnutls-3.2.6.tar.xz, gnutls-3.2.6.tar.xz.sig, gnutls-implement-trust-store-dir,
  gnutls-3.2.6-noecc.patch
* Fri Nov  1 2013 shchang@suse.com
- Upgrade to 3.2.6
  * * libgnutls: Support for TPM via trousers is now enabled by default.
  * * libgnutls: Camellia in GCM mode has been added in default priorities,
  and GCM mode is prioritized over CBC in all of the default priority strings.
  * * libgnutls: Added ciphersuite GNUTLS_ECDHE_RSA_AES_256_CBC_SHA384.
  * * libgnutls: Fixed ciphersuites
  GNUTLS_ECDHE_ECDSA_CAMELLIA_256_CBC_SHA384,
  GNUTLS_ECDHE_RSA_CAMELLIA_256_CBC_SHA384 and
  GNUTLS_PSK_CAMELLIA_128_GCM_SHA256. Reported by Stefan Buehler.
  * * libgnutls: Added support for ISO OID for RSA-SHA1 signatures.
  * * libgnutls: Minimum acceptable DH group parameters were increased to
  767 bits from 727.
  * * libgnutls: Added function to obtain random data from PKCS #11 tokens.
  Contributed by Wolfgang Meyer zu Bergsten.
  * * gnulib: updated.
  * * libdane: Fixed a one-off bug in dane_query_tlsa() introduced by the
  previous fix. Reported by Tomas Mraz.
  * * p11tool: Added option generate-random.
  * * API and ABI modifications:
  gnutls_pkcs11_token_get_random: Added
  Add: gnutls-3.2.6-noecc.patch, gnutls-3.2.6.tar.xz, gnutls-3.2.6.tar.xz.sig
  Delete: gnutls-3.2.6-noecc.patch, gnutls-3.2.5.tar.xz, gnutls-3.2.5.tar.xz.sig,
  make-obs-happy-with-gnutls_3.2.5.patch
* Mon Oct 28 2013 shchang@suse.com
- Upgrade to 3.2.5
  * * libgnutls: Documentation and build-time fixes.
  * * libgnutls: Allow the generation of DH groups of less than 700 bits.
  * * libgnutls: Added several combinations of ciphersuites with SHA256 and
  SHA384 as MAC, as well as Camellia with GCM.
  * * libdane: Added interfaces to allow initialization of dane_query_t
  from external DNS resolutions, and to allow direct verification of a
  certificate chain against a dane_query_t. Contributed by Christian Grothoff.
  * * libdane: Fixed a buffer overflow in dane_query_tlsa(). This could be
  triggered by a DNS server supplying more than 4 DANE records. Report and
  fix by Christian Grothoff.
  * * srptool: Fixed index command line option. Patch by Attila Molnar.
  * * gnutls-cli: Added support for inline commands, using the
--inline-commands-prefix and --inline-commands options. Patch by Raj Raman.
  * * certtool: pathlen constraint is now read correctly. Reported by
  Christoph Seitz.
  * * API and ABI modifications:
  gnutls_certificate_get_crt_raw: Added
  dane_verify_crt_raw: Added
  dane_raw_tlsa: Added
  Add files: make-obs-happy-with-gnutls_3.2.5.patch, gnutls-3.2.5.tar.xz,
  gnutls-3.2.5.tar.xz.sig, gnutls-3.2.5-noecc.patch
  Delete files: gnutls-3.2.4.tar.xz, gnutls-3.2.4.tar.xz.sig,
  make-obs-happy-with-gnutls_3.2.4.patch, gnutls-3.2.4-noecc.patch
* Mon Sep  2 2013 schwab@linux-m68k.org
- Don't run install-info on images
* Mon Sep  2 2013 shchang@suse.com
- Update to 3.2.4
  * * libgnutls: Fixes when session tickets and session DB are used.
  Report and initial patch by Stefan Buehler.
  * * libgnutls: Added the RSA-PSK key exchange. Patch by by Frank Morgner,
  based on previous patch by Bardenheuer GmbH and Bundesdruckerei GmbH.
  * * libgnutls: Added ciphersuites that use ARCFOUR with ECDHE. Patch
  by Stefan Buehler.
  * * libgnutls: Added the PFS priority string option.
  * * libgnutls: Gnulib included files are strictly LGPLv2.
  * * libgnutls: Corrected gnutls_certificate_server_set_request().
  Reported by Petr Pisar.
  * * API and ABI modifications:
  gnutls_record_set_timeout: Exported
  Add files:gnutls-3.2.4.tar.xz.sig, gnutls-3.2.4.tar.xz, gnutls-3.2.4-noecc.patch
  Delete file: gnutls-3.2.3-noecc.patch
* Thu Aug 29 2013 ro@suse.de
- buildrequire valgrind on the same arch list that valgrind builds
* Thu Aug  1 2013 meissner@suse.com
- Updated to 3.2.3
  * * libgnutls: Fixes in parsing of priority strings. Patch by Stefan
    Buehler.
  * * libgnutls: Solve issue with received TLS packets that exceed 2^14.
    (this fixes a bug that was accidentally introduced in 3.2.2)
  * * libgnutls: Removed gnulib modules under LGPLv3 that could possibly
    be used by the library.
  * * libgnutls: Fixes in gnutls_record_send_range(). Report and initial
    fix by Alfredo Pironti.
- Updated to 3.2.2
  * * libgnutls: Several optimizations in the related to packet processing
    subsystems.
  * * libgnutls: DTLS replay detection can now be disabled (to be used
    in certain transport layers like SCTP).
  * * libgnutls: Fixes in SRTP extension generation when MKI is being used.
  * * libgnutls: Added ability to set hooks before or
    after sending or receiving any handshake message with
    gnutls_handshake_set_hook_function().
- gnutls-3.2.3-noecc.patch: updated to disable ECC.
- automake-1.12.patch: upstream, dropped
- gnutls-32bit.patch: upstream, dropped
- gnutls-3.2.1-pkcs11.diff: upstream, dropped
* Fri Jul 26 2013 lnussel@suse.de
- revert to using certificate directory again until gnutls
  understands the trust bits in pkcs11. Otherwise it would use
  blacklisted certificates.
* Mon Jul  8 2013 schwab@suse.de
- Override broken configure checks
* Thu Jul  4 2013 lnussel@suse.de
- use pkcs11 interface to fetch the system's CA certificates
  (fate#314991). Add patch gnutls-3.2.1-pkcs11.diff to fix doing
  that, obsoletes gnutls-implement-trust-store-dir.diff.
* Thu Jun 27 2013 meissner@suse.com
- Disable all ECC algorithms.
- gnutls-32bit.patch: upstream patch to make test
  work with 32bit time_t.
- gnutls-implement-trust-store-dir.diff
  currently not yet forward ported.
- Updated to GnuTLS 3.2.1
  * * libgnutls: Allow ECC when in SSL 3.0 to work-around a bug in certain
    openssl versions.
  * * libgnutls: Fixes in interrupted function resumption. Report
    and patch by Tim Kosse.
  * * libgnutls: Corrected issue when receiving client hello verify
    requests in DTLS.
  * * libgnutls: Fixes in DTLS record overhead size calculations.
  * * libgnutls: gnutls_handshake_get_last_in() was fixed. Reported by
    Mann Ern Kang.
- Updated to GnuTLS 3.2.0
  * * libgnutls: Use nettle's elliptic curve implementation.
  * * libgnutls: Added Salsa20 cipher
  * * libgnutls: Added UMAC-96 and UMAC-128
  * * libgnutls: Added ciphersuites involving Salsa20 and UMAC-96.
    As they are not standardized they are defined using private ciphersuite numbers.
  * * libgnutls: Added support for DTLS 1.2.
  * * libgnutls: Added support for the Application Layer Protocol
    Negotiation (ALPN) extension.
  * * libgnutls: Removed support for the RSA-EXPORT ciphersuites.
  * * libgnutls: Avoid linking to librt (that also avoids unnecessary
    linking to pthreads if p11-kit isn't used).
- Updated to GnuTLS 3.1.10 (released 2013-03-22)
  * * certtool: When generating PKCS #12 files use by default the
  ARCFOUR (RC4) cipher to be compatible with devices that don't
  support AES with PKCS #12.
  * * libgnutls: Load CA certificates in android 4.x systems.
  * * libgnutls: Optimized CA certificate loading.
  * * libgnutls: Private keys are overwritten on deinitialization.
  * * libgnutls: PKCS #11 slots are scanned only when needed, not
    on initialization. This speeds up gnutls initialization when smart
    cards are present.
  * * libgnutls: Corrected issue in the (deprecated) external key
    signing interface, when used with TLS 1.2. Reported by Bjorn H. Christensen.
  * * libgnutls: Fixes in openpgp handshake with fingerprints. Reported by
    Joke de Buhr.
  * * libgnutls-dane: Updated DANE verification options.
  * * configure: Trust store file must be explicitly set or unset when
    cross compiling.
- Updated to GnuTLS 3.1.9 (released 2013-02-27)
  * * certtool: Option --to-p12 will now ask for a password to generate
    a PKCS #12 file from an encrypted key file. Reported by Yan Fiz.
  * * libgnutls: Corrected issue in gnutls_pubkey_verify_data().
  * * libgnutls: Corrected parsing issue in XMPP within a subject
    alternative name. Reported by James Cloos.
  * * libgnutls: gnutls_pkcs11_reinit() will reinitialize all PKCS #11
    modules, and not only the ones loaded via p11-kit.
  * * libgnutls: Added function to check whether the private key is
    still available (inserted).
  * * libgnutls: Try to detect fork even during nonce generation.
- Updated to GnuTLS 3.1.8 (released 2013-02-10)
  * * libgnutls: Fixed issue in gnutls_x509_privkey_import2() which didn't return
    GNUTLS_E_DECRYPTION_FAILED in all cases, and affect certtool operation
    with encrypted keys. Reported by Yan Fiz.
  * * libgnutls: The minimum DH bits accepted by priorities NORMAL and
    PERFORMANCE was set to previous defaults 727 bits. Reported by Diego
    Elio Petteno.
  * * libgnutls: Corrected issue which prevented gnutls_pubkey_verify_hash()
    to operate with long keys. Reported by Erik A Jensen.
- Updated to GnuTLS 3.1.7 (released 2013-02-04)
  * * certtool: Added option "dn" which allows to directly set the DN
    in a template from an RFC4514 string.
  * * danetool: Added options: --dlv and --insecure. Suggested by Paul Wouters.
  * * libgnutls-xssl: Added a new library to simplify GnuTLS usage.
  * * libgnutls-dane: Added function to specify a DLV file.
  * * libgnutls: Heartbeat code was made optional.
  * * libgnutls: Fixes in server side of DTLS-0.9.
  * * libgnutls: DN variable 'T' was expanded to 'title'.
  * * libgnutls: Fixes in record padding parsing to prevent a timing attack.
    Issue reported by Kenny Paterson and Nadhem Alfardan.
  * * libgnutls: Added functions to directly set the DN in a certificate
    or request from an RFC4514 string.
  * * libgnutls: Optimizations in the random generator. The re-seeding of
    it is now explicitly done on every session deinit.
  * * libgnutls: Simplified the DTLS sliding window implementation.
  * * libgnutls: The minimum DH bits accepted by a client are now set
    by the specified priority string. The current values correspond to the
    previous defaults (727 bits), except for the SECURE128 and SECURE192
    strings which increase the minimum to 1248 and 1776 respectively.
  * * libgnutls: Added the gnutls_record_cork() and uncork API to enable
    buffering in sending application data.
  * * libgnutls: Removed default random padding, and added a length-hiding interface
    instead.  Both the server and the client must support this extension. Whether
    length-hiding can be used on a given session can be checked using
    gnutls_record_can_use_length_hiding(). Contributed by Alfredo Pironti.
  * * libgnutls: Added the experimental %%NEW_PADDING priority string. It enables
    a new padding mechanism in TLS allowing arbitrary padding in TLS records
    in all ciphersuites, which makes length-hiding more efficient and solves
    the issues with timing attacks on CBC ciphersuites.
  * * libgnutls: Corrected gnutls_cipher_decrypt2() when used with AEAD
    ciphers (i.e., AES-GCM). Reported by William McGovern.
- Updated to GnuTLS 3.1.6 (released 2013-01-02)
  * * libgnutls: Fixed record padding parsing issue. Reported by Kenny
    Patterson and Nadhem Alfardan.
  * * libgnutls: Several updates in the ASN.1 string handling subsystem.
  * * libgnutls: gnutls_x509_crt_get_policy() allows for a list of zero
    policy qualifiers.
  * * libgnutls: Ignore heartbeat messages when received out-of-order,
    instead of issuing an error.
  * * libgnutls: Stricter RSA PKCS #1 1.5 encoding and decoding. Reported
    by Kikuchi Masashi.
  * * libgnutls: TPM support is disabled by default because GPL programs
    cannot link with it. Use --with-tpm to enable it.
  * * libgnutls-guile: Fixed parallel compilation issue.
  * * gnutls-cli: It will try to connect to all possible returned addresses
    before failing.
- Updated to GnuTLS 3.1.5 (released 2012-11-24)
  * * libgnutls: Added functions to parse the certificates policies
    extension.
  * * libgnutls: Handle BMPString (UCS-2) encoding in the Distinguished
    Name by translating it to UTF-8 (works on windows or systems with
    iconv).
  * * libgnutls: Added PKCS #11 key generation function that returns the
    public key on generation.
  * * libgnutls: Corrected bug in priority string parsing, that mostly
    affected combined levels. Patch by Tim Kosse.
  * * certtool: The --pubkey-info option can be combined with the
  - -load-privkey or --load-request to print the corresponding public keys.
  * * certtool: It is able to set certificate policies via a template.
  * * certtool: Added --hex-numbers option which prints big numbers in
    an easier to parse format.
  * * p11tool: After key generation, outputs the public key (useful in
    tokens that do not store the public key).
  * * danetool: It is being built even without libgnutls-dane (the
  - -check functionality is disabled though).
- Updated to GnuTLS 3.1.4 (released 2012-11-10)
  * * libgnutls: gnutls_certificate_verify_peers2() will set flags depending on
    the available revocation data validity.
  * * libgnutls: Added gnutls_certificate_verification_status_print(),
    a function to print the verification status code in human readable text.
  * * libgnutls: Added priority string %%VERIFY_DISABLE_CRL_CHECKS.
  * * libgnutls: Simplified certificate verification by adding
    gnutls_certificate_verify_peers3().
  * * libgnutls: Added support for extension to establish keys for SRTP.
    Contributed by Martin Storsjo.
  * * libgnutls: The X.509 verification functions check the key
    usage bits and pathlen constraints and on failure output
    GNUTLS_CERT_SIGNER_CONSTRAINTS_FAILURE.
  * * libgnutls: gnutls_x509_crl_verify() includes the time checks.
  * * libgnutls: Added verification flag GNUTLS_VERIFY_DO_NOT_ALLOW_UNSORTED_CHAIN
    and made GNUTLS_VERIFY_ALLOW_UNSORTED_CHAIN the default.
  * * libgnutls: Always tolerate key usage violation errors from the side
    of the peer, but also notify via an audit message.
  * * gnutls-cli: Added --local-dns option.
  * * danetool: Corrected bug that prevented loading PEM files.
  * * danetool: Added --check option to allow querying and verifying
    a site's DANE data.
  * * libgnutls-dane: Added pkg-config file for the library.
- Updated to GnuTLS 3.1.3 (released 2012-10-12)
  * * libgnutls: Added support for the OCSP Certificate Status
    extension.
  * * libgnutls: gnutls_certificate_verify_peers2() will use the OCSP
    certificate status extension in verification.
  * * libgnutls: Bug fixes in gnutls_x509_privkey_import_openssl().
  * * libgnutls: Increased maximum password length in the PKCS #12
    functions.
  * * libgnutls: Fixed the receipt of session tickets during session resumption.
    Reported by danblack at http://savannah.gnu.org/support/?108146
  * * libgnutls: Added functions to export structures in an allocated buffer.
  * * libgnutls: Added gnutls_ocsp_resp_check_crt() to check whether the OCSP
    response corresponds to the given certificate.
  * * libgnutls: In client side gnutls_init() enables the session ticket and
    OCSP certificate status request extensions by default. The flag
    GNUTLS_NO_EXTENSIONS can be used to prevent that.
  * * libgnutls: Several updates in the OpenPGP code. The generating code
    is fully RFC6091 compliant and RFC5081 support is only supported in client
    mode.
  * * libgnutls-dane: Added. It is a library to provide DANE with DNSSEC
    certificate verification.
  * * gnutls-cli: Added --dane option to enable DANE certificate verification.
  * * danetool: Added tool to generate DANE TLSA Resource Records (RR).
- Updated to GnuTLS 3.1.2 (released 2012-09-26)
  * * libgnutls: Fixed bug in gnutls_x509_trust_list_add_system_trust()
    and gnutls_x509_trust_list_add_trust_mem() that prevented the loading
    of certificates in the windows platform.
  * * libgnutls: Corrected bug in OpenPGP subpacket encoding.
  * * libgnutls: Added support for DTLS/TLS heartbeats by Olga Smolenchuk.
    (the work was done during Google Summer of Code).
  * * libgnutls: Added X.509 certificate verification flag
    GNUTLS_VERIFY_ALLOW_UNSORTED_CHAIN. This flag allows the verification
    of unsorted certificate chains and is enabled by default for
    TLS certificate verification (if gnutls_certificate_set_verify_flags()
    does not override it).
  * * libgnutls: Prints warning on certificates that contain keys of
    an insecure level. If the %%COMPAT priority flag is not specified
    the TLS connection fails.
  * * libgnutls: Correctly restore gnutls_record_recv() in DTLS mode
    if interrupted during the retrasmition of handshake data.
  * * libgnutls: Better mingw32 support (patch by LRN).
  * * libgnutls: The %%COMPAT keyword, if specified, will tolerate
    key usage violation errors (they are far too common to ignore).
  * * libgnutls: Added GNUTLS_STATELESS_COMPRESSION flag to gnutls_init(),
    which provides a tool to counter compression-related attacks where
    parts of the data are controlled by the attacker _and_ are placed in
    separate records (use with care - do not use compression if not sure).
  * * libgnutls: Depends on libtasn1 2.14 or later.
  * * certtool: Prints the number of bits of the public key algorithm
    parameter in a private key.
- Updated to GnuTLS 3.1.1 (released 2012-09-02)
  * * gnutls-serv: Listens on IPv6. Patch by Bernhard R. Link.
  * * certtool: Changes in password handling of certtool.
    Ask password when required and only if the '--password' option is not
    given. If the '--password' option is given during key generation then
    assume the PKCS #8 file format, instead of ignoring the password.
  * * tpmtool: No longer asks for key password in registered keys.
  * * libgnutls: Elliptic curve code was optimized by Ilya Tumaykin.
    wmNAF is now used for point multiplication and other optimizations.
    (the major part of the work was done during Google Summer of Code).
  * * libgnutls: The default pull_timeout_function only uses select
    instead of a combination of select() and recv() to prevent issues
    when used in stream sockets in some systems.
  * * libgnutls: Be tolerant in ECDSA signature violations (e.g. using
    SHA256 with a SECP384 curve instead of SHA-384), to interoperate with
    openssl.
  * * libgnutls: Fixed DSA and ECDSA signature generation in smart
    cards. Thanks to Andreas Schwier from cardcontact.de for providing
    me with ECDSA capable smart cards.
- Updated to GnuTLS 3.1.0 (released 2012-08-15)
  * * libgnutls: Added direct support for TPM as a cryptographic module
    in gnutls/tpm.h. TPM keys can be used in functions accepting files
    using URLs of the following types:
    tpmkey:file=/path/to/file
    tpmkey:uuid=7f468c16-cb7f-11e1-824d-b3a4f4b20343;storage=user
  * * libgnutls: Priority string level keywords can be combined.
    For example the string "SECURE256:+SUITEB128" is now allowed.
  * * libgnutls: requires libnettle 2.5.
  * * libgnutls: Use the PKCS #1 1.5 encoding provided by nettle (2.5)
    for encryption and signatures.
  * * libgnutls: Added GNUTLS_CERT_SIGNATURE_FAILURE to differentiate between
    generic errors and signature verification errors in the verification
    functions.
  * * libgnutls: Added gnutls_pkcs12_simple_parse() as a helper function
    to simplify parsing in most PKCS #12 use cases.
  * * libgnutls: gnutls_certificate_set_x509_simple_pkcs12_file() adds
    the whole certificate chain (if any) to the credentials structure, instead
    of only the end-user certificate.
  * * libgnutls: Key import functions such as gnutls_pkcs12_simple_parse()
    and gnutls_x509_privkey_import_pkcs8(), return consistently
    GNUTLS_E_DECRYPTION_FAILED if the input structure is encrypted but no
    password was provided.
  * * libgnutls: Added gnutls_handshake_set_timeout() a function that
    allows to set the maximum time spent in a handshake.
  * * libgnutlsxx: Added session::set_transport_vec_push_function. Patch
    by Alexandre Bique.
  * * tpmtool: Added. It is a tool to generate private keys in the TPM.
  * * gnutls-cli: --benchmark-tls was split to --benchmark-tls-kx
    and --benchmark-tls-ciphers
  * * certtool: generated PKCS #12 structures may hold more than one
    private key. Patch by Lucas Fisher.
  * * certtool: Added option --null-password to generate/decrypt keys
    that use a NULL password (in schemas that distinguish between NULL
    an empty passwords).
  * * minitasn1: Upgraded to libtasn1 version 2.13.
- Library is now LGPL-2.1+, extras and tools are still GPL-3.0
* Fri Apr 26 2013 mmeister@suse.com
- Added makeinfo BuildRequire to fix build with new automake
* Tue Feb  5 2013 meissner@suse.com
- Updated to GnuTLS 3.0.28
  - libgnutls: Fixes in server side of DTLS-0.9.
  - libgnutls: Corrected gnutls_cipher_decrypt2() when used with AEAD
    ciphers (i.e., AES-GCM).
  - libgnutls: Fixes in record padding parsing to prevent a timing
    attack. Issue reported by Kenny Patterson and Nadhem Alfardan.
    bnc#802184
  - libgnutls: DN variable 'T' was expanded to 'title'.
* Thu Jan 24 2013 meissner@suse.com
- Updated to GnuTLS 3.0.27
  - libgnutls: Fixed record padding parsing issue.
  - libgnutls: Stricter RSA PKCS #1 1.5 encoding.
  - libgnutls-guile: Fixed parallel compilation issue.
  - API and ABI modifications: No changes since last version.
* Tue Nov 27 2012 crrodriguez@opensuse.org
- Test suite breaks on qemu-arm some calls not implemented.
* Sun Nov 25 2012 andreas.stieger@gmx.de
- include LGPL-3.0+ text in COPYING.LESSER
- run regression tests, but move "make check" to %%check section
- add gnutls-3.0.26-skip-test-fwrite.patch to skip a failing test
- no longer manipulate doc/examples tree in %%install section, the
  deletion of Makefiles breaks "make check" in %%check
- install documentation, reference and examples in %%install section
  to fetch them for the package without unneccessary files
* Fri Nov 16 2012 andreas.stieger@gmx.de
- updated to GnuTLS 3.0.26:
  - libgnutls: Always tolerate key usage violation errors from the
  side of the peer, but also notify via an audit message.
  - libgnutls: gnutls_x509_crl_verify() includes time checks.
  - libgnutls: Increased maximum password length in the PKCS #12
  functions.
  - API and ABI modifications:
  GNUTLS_CERT_REVOCATION_DATA_TOO_OLD: Added
  GNUTLS_CERT_REVOCATION_DATA_ISSUED_IN_FUTURE: Added
- includes changes from 3.0.25:
  - libgnutls: Fixed the receipt of session tickets during session
  resumption.
  - libgnutls: Added gnutls_ocsp_resp_check_crt() to check whether the
  OCSP response corresponds to the given certificate.
  - libgnutls: Several updates in the OpenPGP code. The generating code
  is fully RFC6091 compliant and RFC5081 support is only supported in
  client mode.
  - API and ABI modifications:
  gnutls_ocsp_resp_check_crt: Added
- includes changes form version 3.0.24:
  - libgnutls: The %%COMPAT keyword, if specified, will tolerate
  key usage violation errors (they are far too common to ignore).
  - libgnutls: Corrected bug in OpenPGP subpacket encoding.
  - libgnutls: Added X.509 certificate verification flag
  - GNUTLS_VERIFY_ALLOW_UNSORTED_CHAIN. This flag allows the verification
  of unsorted certificate chains and is enabled by default for
  TLS certificate verification (if gnutls_certificate_set_verify_flags()
    does not override it).
  - libgnutls: Correctly restore gnutls_record_recv() in DTLS mode
  if interrupted during the retrasmition of handshake data.
  - libgnutls: Added GNUTLS_STATELESS_COMPRESSION flag to gnutls_init(),
  which provides a tool to counter compression-related attacks where
  parts of the data are controlled by the attacker _and_ are placed in
  separate records (use with care - do not use compression if not sure).
  - libgnutls: Depends on libtasn1 2.14 or later.
- includes changes from version 3.0.23:
  - gnutls-serv: Listens on IPv6
  - libgnutls: Be tolerant in ECDSA signature violations (e.g. using
  SHA256 with a SECP384 curve instead of SHA-384), to interoperate with
  openssl.
- libgnutls: Fixed DSA and ECDSA signature generation in smart cards.
- includes changes from version 3.0.22
  - libgnutls: When verifying a certificate chain make sure it is chain.
  If the chain is wronly interrupted at some point then truncate it,
  and only try to verify the correct part. Patch by David Woodhouse
  - libgnutls: Restored the behavior of gnutls_x509_privkey_import_pkcs8()
  which now may (again) accept a NULL password.
  - certtool: Allow the user to choose the hash algorithm
  when signing certificate request or certificate revocation list.
- Refresh gnutls-implement-trust-store-dir.diff, some parts are in
  upstream sources
* Mon Jul 16 2012 gjhe@suse.com
- update to latest stable version 3.0.21:
  libgnutls: fixed bug in gnutls_x509_privkey_import()
  that prevented the loading of EC private keys when DER
  encoded. Reported by David Woodhouse.
  libgnutls: In DTLS larger to mtu records result to
  GNUTLS_E_LARGE_PACKET instead of being truncated.
  libgnutls: gnutls_dtls_get_data_mtu() is more precise. Based
  on patch by David Woodhouse.
  libgnutls: Fixed memory leak in PKCS #8 key import.
  libgnutls: Added support for an old version of the DTLS protocol
  used by openconnect vpn client for compatibility with Cisco's AnyConnect
  SSL VPN. It is marked as GNUTLS_DTLS0_9. Do not use it for newer protocols
  as it has issues.
  libgnutls: Corrected bug that prevented resolving PKCS #11 URLs
  if only the label is specified. Patch by David Woodhouse.
  libgnutls: When EMSGSIZE errno is seen then GNUTLS_E_LARGE_PACKET
  is returned.
  API and ABI modifications:
  gnutls_dtls_set_data_mtu: Added
  gnutls_session_set_premaster: Added
* Sun Jul  1 2012 coolo@suse.com
- merge am-1.12 patches into 1
* Sat Jun 30 2012 i@marguerite.su
- fix 12.2 builds.
  * replace depreciated am_prog_mkdir_p with ac_prog_mkdir_p.
* Thu Jun 21 2012 meissner@suse.com
- Updated to version 3.0.20:
  libgnutls: Corrected bug which prevented the parsing of
  handshake packets spanning multiple records.
  libgnutls: Check key identifiers when checking for an issuer.
  libgnutls: Added gnutls_pubkey_verify_hash2()
  libgnutls: Added gnutls_certificate_set_x509_system_trust()
  that loads the trusted CA certificates from system locations
  (e.g. trusted storage in windows and CA bundle files in other systems).
  certtool: Added support for the URI subject alternative
  name type in certtool.
  certtool: Increase to 128 the maximum number of distinct options
  (e.g. dns_names) allowed.
  gnutls-cli: If --print-cert is given, print the certificate,
  even on verification failure.
  * * API and ABI modifications:
  gnutls_pk_to_sign: Added
  gnutls_pubkey_verify_hash2: Added
  gnutls_certificate_set_x509_system_trust: Added
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Thu May 24 2012 lnussel@suse.de
- backport gnutls_certificate_set_x509_system_trust() from git and
  add support for trust store directories (bnc#761634)
* Mon May 21 2012 lnussel@suse.de
- add version and release to gnutls-devel provides
* Mon May 21 2012 meissner@suse.com
- let libgnutls-devel also provide gnutls-devel
* Sun May 13 2012 Nico.Laus.2001@gmx.de
- Update to version 3.0.19:
  + libgnutls:
  - When decoding a PKCS #11 URL the pin-source field
    is assumed to be a file that stores the pin. Based on patch
    by David Smith.
  - gnutls_record_check_pending() no longer
    returns unprocessed data, and thus ensure the non-blocking
    of the next call to gnutls_record_recv().
  - Added strict tests in Diffie-Hellman and
    SRP key exchange public keys.
  - in ECDSA and DSA TLS 1.2 authentication be less
    strict in hash selection, and allow a stronger hash to
    be used than the appropriate, to improve interoperability
    with openssl.
  + tests:
  - Disabled floating point test, and corrections
    in pkcs12 decoding tests.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.18:
  + certtool:
  - Avoid a Y2K38 bug when generating certificates.
    Patch by Robert Millan.
  + libgnutls:
  - Make sure that GNUTLS_E_PREMATURE_TERMINATION
  - is returned on premature termination (and added unit test).
  - Fixes for W64 API. Patch by B. Scott Michel.
  - Corrected VIA padlock detection for old
    VIA processors. Reported by Kris Karas.
  - Updated assembler files.
  - Time in generated certificates is stored
    as GeneralizedTime instead of UTCTime (which only stores
    2 digits of a year).
  + minitasn1:
  - Upgraded to libtasn1 version 2.13 (pre-release).
  + API and ABI modifications:
  - gnutls_x509_crt_set_private_key_usage_period: Added
  - gnutls_x509_crt_get_private_key_usage_period: Added
  - gnutls_x509_crq_set_private_key_usage_period: Added
  - gnutls_x509_crq_get_private_key_usage_period: Added
  - gnutls_session_get_random: Added
- Changes from version 3.0.17:
  + command line apps:
  - Always link with local libopts.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.16:
  + minitasn1:
  - Upgraded to libtasn1 version 2.12 (pre-release).
  + libgnutls:
  - Corrected SRP-RSA ciphersuites when used under TLS 1.2.
  - included assembler files for MacOSX.
  + p11tool:
  - Small fixes in handling of the --private command
    line option.
  + certtool:
  - The template option allows for setting the domain
    component (DC) option of the distinguished name, and the ocsp_uri
    as well as the ca_issuers_uri options.
  + API and ABI modifications:
  - gnutls_x509_crt_set_authority_info_access: Added
- Changes from version 3.0.15:
  + test suite:
  - Only run under valgrind in the development
    system (the full git repository)
  + command line apps:
  - Link with local libopts if the installed is an old one.
  + libgnutls:
  - Eliminate double free during SRP
    authentication. Reported by Peter Penzov.
  - Corrections in record packet parsing.
    Reported by Matthew Hall.
  - Cryptodev updates and fixes.
  - Corrected issue with select() that affected
    FreeBSD. This prevented establishing DTLS sessions.
    Reported by Andreas Metzler.
  - Corrected rehandshake and resumption
    operations in DTLS. Reported by Sean Buckheister.
  - PKCS #11 objects that do not have ID
    no longer crash listing. Reported by Sven Geggus.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.14:
  + command line apps:
  - Included libopts doesn't get installed by default.
  + libgnutls:
  - Eliminate double free on wrongly formatted
    certificate list. Reported by Remi Gacogne.
  - cryptodev code corrected, updated to account
    for hashes and GCM mode.
    Eliminated memory leak in PCKS #11 initialization.
    Report and fix by Sam Varshavchik.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.13:
  + gnutls-cli:
  - added the --ocsp option which will verify
    the peer's certificate with OCSP.
  - added the --tofu and if specified, gnutls-cli
    will use an ssh-style authentication method.
  - if no --x509cafile is provided a default is
    assumed (/etc/ssl/certs/ca-certificates.crt), if it exists.
  + ocsptool:
  - Added --ask parameter, to verify a certificate's
    status from an ocsp server.
  + command line apps:
  - Use gnu autogen (libopts) to parse command
    line arguments and template files.
  + tests:
  - Added stress test for DTLS packet losses and
    out-of-order receival. Contributed by Sean Buckheister.
  + libgnutls:
  - Several updates and corrections in the DTLS
    DTLS lost packet handling and retransmission timeouts.
    Report and patches by Sean Buckheister.
  - Added new functions to easily allow the usage of
    a trust on first use (SSH-style) authentication.
  - SUITEB128 and SUITEB192 priority strings account
    for the RFC6460 requirements.
  - Added new security parameter GNUTLS_SEC_PARAM_LEGACY
    to account for security level of 96-bits.
  - In client side if server does not advertise any
    known CAs and only a single certificate is set in the credentials,
    sent that one.
  - Added functions to parse authority key identifiers
    when stored as a 'general name' and serial combo.
  - Added function to force explicit reinitialization
    of PKCS #11 modules. This is required on the child process after
    a fork (if PKCS #11 functionality is desirable).
  - Depend on p11-kit 0.11.
  + API and ABI modifications:
  - gnutls_dtls_get_timeout: Added
  - gnutls_verify_stored_pubkey: Added
  - gnutls_store_pubkey: Added
  - gnutls_store_commitment: Added
  - gnutls_x509_crt_get_authority_key_gn_serial: Added
  - gnutls_x509_crl_get_authority_key_gn_serial: Added
  - gnutls_pkcs11_reinit: Added
  - gnutls_ecc_curve_list: Added
  - gnutls_priority_certificate_type_list: Added
  - gnutls_priority_sign_list: Added
  - gnutls_priority_protocol_list: Added
  - gnutls_priority_compression_list: Added
  - gnutls_priority_ecc_curve_list: Added
  - gnutls_tdb_init: Added
  - gnutls_tdb_set_store_func: Added
  - gnutls_tdb_set_store_commitment_func: Added
  - gnutls_tdb_set_verify_func: Added
  - gnutls_tdb_deinit: Added
- Changes from version 3.0.12:
  + libgnutls:
  - Added OCSP support.
    There is a new header file gnutls/ocsp.h and a set of new functions
    under the gnutls_ocsp namespace.  Currently the functionality provided
    is to parse and extract information from OCSP requests/responses, to
    generate OCSP requests and to verify OCSP responses.  See the manual
    for more information.  Run ./configure with --disable-ocsp to build
    GnuTLS without OCSP support.
    This work was sponsored by Smoothwall <http://smoothwall.net/>.
  + ocsptool:
  - Added new command line tool.
    The tool can parse OCSP request/responses, generate OCSP requests and
    verify OCSP responses.  See the manual for more information.
  + certtool:
  - --outder option now works for private
    and public keys as well.
  + libgnutls:
  - Added error code GNUTLS_E_NO_PRIORITIES_WERE_SET
    to warn when no or insufficient priorities were set.
  - Corrected an alignment issue in ECDH
    key generation which prevented some keys from being
    correctly aligned in rare circumstances.
  - Corrected memory leaks in DH parameter
    generation and ecc_projective_check_point().
  - Added gnutls_x509_dn_oid_name() to
    return a descriptive name of a DN OID.
  + API and ABI modifications:
  - gnutls_pubkey_encrypt_data: Added
  - gnutls_x509_dn_oid_name: Added
  - gnutls_session_resumption_requested: Added
  - gnutls/ocsp.h: Added new header file.
  - gnutls_ocsp_print_formats_t: Added new type.
  - gnutls_ocsp_resp_status_t: Added new type.
  - gnutls_ocsp_cert_status_t: Added new type.
  - gnutls_x509_crl_reason_t: Added new type.
  - gnutls_ocsp_req_add_cert: Added.
  - gnutls_ocsp_req_add_cert_id: Added.
  - gnutls_ocsp_req_deinit: Added.
  - gnutls_ocsp_req_export: Added.
  - gnutls_ocsp_req_get_cert_id: Added.
  - gnutls_ocsp_req_get_extension: Added.
  - gnutls_ocsp_req_get_nonce: Added.
  - gnutls_ocsp_req_get_version: Added.
  - gnutls_ocsp_req_import: Added.
  - gnutls_ocsp_req_init: Added.
  - gnutls_ocsp_req_print: Added.
  - gnutls_ocsp_req_randomize_nonce: Added.
  - gnutls_ocsp_req_set_extension: Added.
  - gnutls_ocsp_req_set_nonce: Added.
  - gnutls_ocsp_resp_deinit: Added.
  - gnutls_ocsp_resp_export: Added.
  - gnutls_ocsp_resp_get_certs: Added.
  - gnutls_ocsp_resp_get_extension: Added.
  - gnutls_ocsp_resp_get_nonce: Added.
  - gnutls_ocsp_resp_get_produced: Added.
  - gnutls_ocsp_resp_get_responder: Added.
  - gnutls_ocsp_resp_get_response: Added.
  - gnutls_ocsp_resp_get_signature: Added.
  - gnutls_ocsp_resp_get_signature_algorithm: Added.
  - gnutls_ocsp_resp_get_single: Added.
  - gnutls_ocsp_resp_get_status: Added.
  - gnutls_ocsp_resp_get_version: Added.
  - gnutls_ocsp_resp_import: Added.
  - gnutls_ocsp_resp_init: Added.
  - gnutls_ocsp_resp_print: Added.
  - gnutls_ocsp_resp_verify: Added.
- Changes from version 3.0.11:
  + libgnutls:
  - Corrected functionality of
    gnutls_record_get_direction(). Reported by Philip Allison.
  - Provide less timing information when decoding
  TLS/DTLS record packets. Patch by Nadhem Alfardan.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.10:
  + gnutls-cli/serv:
  - Set don't fragment bit in DTLS sessions
  in Linux as well as in BSD.
  + gnutls-cli:
  - Fixed reading from windows terminals.
  + libgnutls:
  - When GNUTLS_OPENPGP_FMT_BASE64 is specified
    the stream is assumed to be base64 encoded (previously
    the encoding was auto-detected). This avoids a decoding
    issue in windows systems.
  - Corrected ciphersuite GNUTLS_ECDHE_PSK_AES_256_CBC_SHA384
  - Added ciphersuites: GNUTLS_PSK_WITH_AES_256_GCM_SHA384
    and GNUTLS_DHE_PSK_WITH_AES_256_GCM_SHA384.
  - Added function gnutls_random_art() to convert
    fingerprints to images (currently ascii-art).
  - Corrected bug in DSA private key parsing, which
    prevented the verification of the key.
  + API and ABI modifications:
  - gnutls_random_art: Added
- Changes from version 3.0.09:
  + certtool:
  - Added new parameter --dh-info.
  - -l option was overloaded so if combined with --priority
    it will only list the ciphersuites that are enabled by the given
    priority string.
  + libgnutls:
  - Added new priority string %%SERVER_PRECEDENCE, which
    changes the ciphersuite selection procedure. If specified the server
    priorities will be used for selection instead of the client's.
  - Optimizations in Diffie-Hellman parameters generation
    and key exchange.
  - When session tickets are negotiated and used in a
    session, a server will not store that session data into its cache.
  - Added the SECP192R1 curve.
  - Added gnutls_priority_get_cipher_suite_index() to
    allow listing the ciphersuites enabled in a priority structure.
    It outputs an index to be used in gnutls_get_cipher_suite_info().
  - Optimizations in the elliptic curve code --timing
    attacks resistant code is only used in ECDSA private key operations.
  + doc:
  - man pages for API functions generation was fixed and are
    now added again in the distribution.
  + API and ABI modifications:
  - GNUTLS_ECC_CURVE_SECP192R1: New curve definition
  - gnutls_priority_get_cipher_suite_index: Added
- Changes from version 3.0.08:
  + certtool:
  - Certtool -e returns error code on verification failure.
  - Verifies parameters of generated keys.
  + libgnutls:
  - Corrected ECC key generation (introduced in 3.0.6)
  - Provide less timing information when decoding
    TLS/DTLS record packets.
  + doc:
  - man pages for API functions were removed.
    The reason was that the code that auto-generated the man pages missed
    many APIs and we couldn't fix it (volunteers welcome).  See the info
    manual or the GTK-DOC manual instead.
  + API and ABI modifications:
  - gnutls_x509_privkey_verify_params: Added
- Changes from version 3.0.07:
  + libgnutls:
  - Corrected fix in gnutls_session_get_data()
    to report the actual session size when the provided buffer
    is not enough.
  - Fixed ciphersuite GNUTLS_ECDHE_RSA_AES_128_CBC_SHA256,
    which was using a wrong MAC algorithm. Reported by Fabrice Gautier.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.06:
  + gnutls-guile:
  - Compilation fixes.
  + libgnutls:
  - Fixed possible buffer overflow in
    gnutls_session_get_data(). Reported and fix by Alban Crequy.
  - Bug fixes in the ciphersuites with NULL cipher.
    Reported by Fabrice Gautier.
  - Bug fixes in ECC code for 64-bit MIPS systems.
    Thanks to Joseph Graham for providing access to such a system.
  - Correctly report ECC private key parsing errors.
    Reported by Fabrice Gautier.
  - In ECDHE verify that the received point lies on
    the selected curve. The ECDHE ciphersuites now take precendence
    to plain DHE.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.05:
  + libgnutls-extra:
  - is no more
  + libgnutls:
  - Corrections in order to compile with mingw32.
  - Corrections in VIA padlock code for VIA C5 processor
    and new detection of PHE with support for partial hashing.
  - Corrected bug in gnutls_x509_data2hex. Report and fix
    by Vincent Untz.
  + minitasn1:
  - Upgraded to libtasn1 version 2.10.
  + API and ABI modifications:
  - No changes since last version.
- Changes from version 3.0.04:
  + gnutls-cli-debug:
  - Added more tests including AES-GCM, SHA256 and elliptic curves.
  + gnutls-cli:
  - Added --benchmark-soft-ciphers to benchmark
    the software version of the ciphers instead of hw accelerated
    (where available)
  + libgnutls:
  - Public key ID calculation is consistent among
    all structures. It uses a SHA-1 hash of the subjectPublicKeyInfo.
  - gnutls_privkey_t allows setting external callback
    to perform signing or decryption. Can be set using
    gnutls_privkey_import_ext()
  - A certificate credentials structure can be
    used with a gnutls_privkey_t and a gnutls_pcert_st
    structure using gnutls_certificate_set_key().
  - Fixes to enable external signing callback to
    operate with TLS 1.2.
  - Fixed crash when printing ECDSA certificate key
    ID. Reported by Erik Jensen.
  - Corrected VIA padlock code for C3. In C3 benchmarks
    show a 2x increase in AES speed and a 14x increase in VIA nano. Added
    support for hashes and HMACs.
  - Compilation fixed when p11-kit is not detected.
  - Fixed the deflate compression code.
  - Added gnutls_x509_crt_get_authority_info_access.
    Used to get the PKIX Authority Information Access (AIA) field.
  - gnutls_x509_crt_print supports printing AIA fields.
  - Added ability to gnutls_privkey_t to operate with
    signing callback function.
  + API and ABI modifications:
  - gnutls_x509_crt_get_authority_info_access (x509.h): Added function.
  - gnutls_privkey_import_ext: Added function.
  - gnutls_certificate_set_key: Added function.
  - gnutls_info_access_what_t (x509.h): Added enum.
  - GNUTLS_OID_AIA (x509.h): Added symbol.
  - GNUTLS_OID_AD_OCSP (x509.h): Added symbol.
  - GNUTLS_OID_AD_CAISSUERS (x509.h): Added symbol.
- Drop CVE-2011-4128.patch, CVE-2012-0390.patch, CVE-2012-1569.patch,
  CVE-2012-1573.patch, gnutls-fix-compression.patch,
  gnutls-fix-crash-on-strcat.patch: all fixed upstream.
* Thu Apr 12 2012 gjhe@suse.com
- fix bug[bnc#753301] - VUL-0: gnutls/libtasn1
  "asn1_get_length_der()" DER decoding issue
  CVE-2012-1569
  and bug[bnc#754223] - GenericBlockCipher heap corruption DoS
  CVE-2012-1573
* Mon Feb 13 2012 gjhe@suse.com
- fix Bug[bnc#739898] - VUL-1: CVE-2012-0390: GnuTLS DTLS plaintext
  recovery attack.
* Wed Nov 30 2011 vuntz@opensuse.org
- Fix licenses (bnc#733661): the applications as well as
  gnutls-extra and gnutls-openssl libraries are under GPL-3.0+
  while the library is LGPL-3.0+.
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Mon Nov 14 2011 gjhe@suse.com
- fix #Bug 729486 - gnutls: buffer overflow
  CVE-2011-4128
* Mon Oct 17 2011 vuntz@opensuse.org
- Add gnutls-fix-crash-on-strcat.patch: make sure a string is
  nul-terminated before using strcat on it. Fix bnc#724421.
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: configure with sysroot
* Sat Sep 24 2011 vuntz@opensuse.org
- Add gnutls-fix-compression.patch: fix some
  decompression/compression issues that caused connection failures
  to some XMPP servers. Patch taken from git.
* Fri Sep 23 2011 meissner@suse.de
- added libgnutls-devel to baselibs.conf for 32bit Wine on 64bit build
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.0.3:
  + libgnutls:
  - Added gnutls_record_get_discarded() to return the number of
    discarded records in a DTLS session.
  - All functions related to RSA-EXPORT were deprecated.
  - Memory leak fixes in credentials private key
    deinitialization.
  - Memory leak fixes in ECC ciphersuites.
  - Do not send an empty extension structure in server hello.
    This affected old implementations that do not support
    extensions.
  - Allow CA importing of 0 certificates to succeed.
  - Added support for VIA padlock AES optimizations. (disabled by
    default)
  - Added support for elliptic curves in PKCS #11.
  - Added gnutls_pkcs11_privkey_generate() to allow generating a
    key in a token.
  - gnutls_transport_set_lowat dummy macro was removed.
  + p11tool: Added generate-rsa, generate-dsa and generate-ecc
    options to allow generating private keys in the token.
- Changes from version 3.0.2:
  + libgnutls:
  - OpenPGP certificate type is not enabled by default.
  - Added %%NO_EXTENSIONS priority string.
  - Corrected issue in gnutls_record_recv() triggered on
    encryption or compression error.
  - Compatibility fixes in CPU ID detection for i386 and old GCC.
  - Corrected parsing of XMPP subject alternative names.
  - Allow for out-of-order ChangeCipherSpec message in DTLS.
  - gnutls_certificate_set_x509_key() and
    gnutls_certificate_set_openpgp_key() operate as in 2.10.x and
    allow the release of the private key during the lifetime of
    the certificate structure.
  + gnutls-cli: Benchmark applications were incorporated with it.
- Changes from version 3.0.1:
  + libgnutls:
  - gnutls_certificate_set_x509_key_file() and friends support
    server name indication. If multiple certificates are set
    using these functions the proper one will be selected during
    a handshake.
  - Added AES-256-GCM which was left out from the previous
    release.
  - When asking for a PKCS# 11 PIN multiple times, the flags in
    the callback were not being updated to reflect for PIN low
    count or final try.
  - Do not allow second instances of PKCS #11 modules.
  - Fixed alignment issue in AES-NI code.
  - The config file at gnutls_pkcs11_init() is being read if
    provided.
  - Ensure that a certificate list specified using
    gnutls_certificate_set_x509_key() and friends, is sorted
    according to TLS specification (from subject to issuer).
  - Added GNUTLS_X509_CRT_LIST_FAIL_IF_UNSORTED flag for
    gnutls_x509_crt_list_import. It checks whether the list to be
    imported is properly sorted.
  + crywrap: Added to the distribution. It is an application that
    proxies TLS session to a port using a plaintext service.
  + Many GTK-DOC improvements.
  + Updated translations.
- Drop 0001-Included-appro-s-updates-to-AES-NI.patch,
  0002-Added-note.GNU-stack-to-prevent-marking-the-library-.patch,
  0003-Force-alignment-for-AES-NI-to-the-runtime-rather-tha.patch,
  0006-Added-AES-256-GCM.-Reported-by-Benjamin-Hof.patch: all fixed
  upstream.
- Drop call to autoreconf: it was only needed for the patches.
- Add libidn-devel BuildRequires for the new crywrap tool.
* Mon Aug 29 2011 coolo@novell.com
- update baselibs.conf
* Wed Aug 17 2011 crrodriguez@opensuse.org
- Update to version 3.0.0. many fixes see NEWS for details This
  changelog only describes important package changes or features.
  * Main reason for update is to support Intel AES-NI CPU extensions.
  * Bump sonames in the library package accordingly
  * C++ apps must now buildrequire libgnutls++-devel
  * Software using the openssl emulation must buildrequire
  libgnutls-openssl-devel or better use openssl directly.
  * Upstream no longer uses libgcrypt but libnettle.
  * Upstream now requires the use of p11-kit
  * Add post-release upstream patches critical for improving AES-NI
  support.
* Thu Jun 23 2011 gjhe@novell.com
- update to stable version 2.10.5
  * * libgnutls: Corrected verification of finished messages.
  * * libgnutls: Corrected signature generation and verification
    in the Certificate Verify message when in TLS 1.2. Reported
    by Todd A. Ouska.
  * * pkg-config gnutls.pc improvements.
    The file uses 'Requires.private' for libtasn1 and libz when needed,
    instead of Libs.private.  From Andreas Metzler.
  * * gnutls-serv: Corrected a buffer overflow. Reported and patch by Tomas Mraz.
  * * libgnutls: Use ASN1_NULL when writing parameters for RSA signatures.
    This makes us comply with RFC3279. Reported by Michael Rommel.
  * * libgnutls: Reverted default behavior for verification and
    introduced GNUTLS_VERIFY_DO_NOT_ALLOW_X509_V1_CA_CRT. Thus by default
    V1 trusted CAs are allowed, unless the new flag is specified.
  * * minitasn1: Updated to Libtasn1 2.9.
  * * bgnutls: Correctly add leading zero to PKCS #8 encoded DSA key.
    Reported by Jeffrey Walton.
  * * libgnutls: Corrected memory leak in extension data calculation.
    Reported by Mike Blumenkrantz.
  * * libgnutls: Remove trailing comma in enums in gnutls.h and x509.h.
  * * API and ABI modifications:
    No changes since last version.
* Mon Oct 11 2010 gjhe@novell.com
- update to latest stable version 2.10.2
  * tons of changes, see NEWS
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Apr 15 2010 meissner@suse.de
- updated to stable 2.8.6
  * * libgnutls: For CSRs, don't null pad integers for RSA/DSA value.
    VeriSign rejected CSRs with this padding.
    Note: As a side effect of this change, the "public key identifier"
    value computed for a certificate using this version of GnuTLS will be
    different from values computed using earlier versions of GnuTLS.
  * * libgnutls: For CSRs on DSA keys, don't add DSA parameters to the
    optional SignatureAlgorithm parameter field.
    VeriSign rejected these CSRs.  They are stricly speaking not needed
    since you need the signer's certificate to verify the certificate
    signature anyway.
  * * libgnutls: When checking openpgp self signature also check the signatures
    of all subkeys.
    Ilari Liusvaara noticed and reported the issue and provided test
    vectors as well.
  * * libgnutls: Cleanups and several bug fixes.
    Found by Steve Grubb and Tomas Mraz.
  * * Link libgcrypt explicitly to certtool, gnutls-cli, gnutls-serv.
  * * Fix --disable-valgrind-tests.
  * * examples: Use the new APIs for printing X.509 certificate information.
  * * i18n: Updated Czech, Dutch, French, Polish, Swedish and Vietnamese
    translations.  Added Simplified Chinese translation.
* Tue Apr  6 2010 crrodriguez@opensuse.org
- use system libtasn1 instead of the bundled copy
* Thu Feb  4 2010 meissner@suse.de
- some build fixes.
* Thu Feb  4 2010 per@osbeck.com
- updated to stable 2.8.5
* Fri Dec 25 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Sep  2 2009 gjhe@novell.com
- update to lastest stable version 2.8.3
  [bnc#532750]
* Fri Mar 13 2009 jshi@suse.de
- fix security bug [bnc#457938]
  new CVE-2008-4989
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Fri Nov 28 2008 jshi@suse.de
- fix security bug [bnc#441856]
  CVE-2008-4989
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sat Aug  2 2008 meissner@suse.de
- run testsuite
* Thu Jul 17 2008 mkoenig@suse.de
- update to version 2.4.1
  * libgnutls: Fix local crash in gnutls_handshake
  * libgnutls: Fix memory leaks when doing a re-handshake
  * Fix compiler warnings
  * Fix ordering of -I's to avoid opencdk.h conflict with
    system headers
  * srptool: Fix a problem where --verify check does not succeed
- remove C++ wrapper lib, it is not usable without SRP
- remove patch
  gnutls-1.6.1-srptool.patch
* Wed Jul  2 2008 mkoenig@suse.de
- remove gnutls main package from baselibs.conf
* Thu Jun 26 2008 mkoenig@suse.de
- update to version 2.4.0
  * The OpenPGP sub-system has been improved and now supports subkeys
  * The PSK sub-system has been improved and now supports password
    derivation and PSK identity hints
  * The certtool --inder and --outder has been replaced
    by --inraw and --outraw
  * New APIs to access the raw X.509 Subject and Issuer DN's and
    elements from the certificate credentials structure
  * New APIs to improve working with username/passwords and PSK
  * Names of constants to affect certificate printing changed
  * The function gnutls_openpgp_privkey_get_id has been renamed to
    gnutls_openpgp_privkey_get_key_id
  * API/ABI changes in GnuTLS 2.4
    All OpenPGP related functions have been moved from
    libgnutls-extra to libgnutls, and several new functions have
    been added
- remove SRP functionality from C++ wrapper, otherwise it cannot
  be linked against it
- removed patches
  gnutls-2.2.2-uninitialized.patch
  gnutls-char-signedness.patch
  gnutls-GNUTLS_SA_2008_1.patch
* Mon Jun 23 2008 mkoenig@suse.de
- disable SRP [bnc#65192]
* Wed May 21 2008 mkoenig@suse.de
- fix three security bugs [bnc#392947]
  CVE-2008-1948 GNUTLS-SA-2008-1-1
  Fix crash when sending invalid server name
  CVE-2008-1949 GNUTLS-SA-2008-1-2
  Fix crash when sending repeated client hellos
  CVE-2008-1950 GNUTLS-SA-2008-1-3
  Fix crash in cipher padding decoding for invalid record lengths
* Thu May  8 2008 mkoenig@suse.de
- fix build
* Tue Apr 29 2008 cthiel@suse.de
- obsolete gnutls-<arch> via baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 mkoenig@suse.de
- update to version 2.2.2
  * Cipher priority string handling now handle strings that
    starts with NULL
  * Corrected memory leaks in session resuming and DHE ciphersuites
  * Increased the default certificate verification chain limits and
    allowed for checks without limitation
  * Corrected the behaviour of gnutls_x509_crt_get_subject_alt_name()
    and gnutls_x509_crt_get_subject_alt_name() to not null terminate
    binary strings and return the proper size
* Thu Jan 31 2008 mkoenig@suse.de
- update to version 2.2.1
  * Fixes the post_client_hello_function()
  * Fix for certificate selection in servers with certificate callbacks
  * certtool: Fixed data corruption when using --outder
  * TLS authorization support removed.
  * Corrected bug which did not allow a server to run without
    supporting certificates
  * Introduced gnutls_session_enable_compatibility_mode()
  * Added gnutls_record_disable_padding() to allow servers talking to
    buggy clients
  * Fixed PKCS #3 parameter export
  * Added support for Camellia cipher
  * certtool: Add option --quick-random
  * Added capability to set a callback after the client hello is
    received by the server in order to adjust parameters before
    the handshake
  * certtool: Fixed data corruption when using --outder
  * SRP was corrected to adhere to the latest draft
  * Updated the DN parser
  * Added support for DSA2 using libgcrypt 1.3.0
  * Removed all the trustdb code from openpgp authentication.
    We now use only the well-specified keyrings
  * The gnutls_certificate_set_openpgp_* functions were modified
    to include the format. This makes the interface consistent with
    the x509 functions
  * Introduced gnutls_session_enable_compatibility_mode()
  * Added gnutls_set_default_priority2()
  * Added priority functions that accept strings
  * certtool: Add option --disable-quick-random to enable the
    old behaviour of using /dev/random to generate keys
  * Added the --v1 option to certtool, to allow generating X.509
    version 1 certificates
  * Fix PKCS#3 parameter export problem
  * Fixed GNUTLS_E_UNKNOWN_ALGORITHM vs GNUTLS_E_UNKNOWN_HASH_ALGORITHM
  * gnutls_certificate_set_x509_key_* can now read PKCS #8 unencrypted
    private keys
  * Introduced the GNUTLS_E_BASE64_UNEXPECTED_HEADER_ERROR error code
  * Added the --to-p8 option to certtool to convert private keys
    to PKCS #8 keys
  * Corrected bug in decompression of expanded compression data
  * The gnutls_*_convert_priority() functions were deprecated
  * gnutls-cli and gnutls-serv now have a --priority option
  * PKCS #8 parser can now encode/decode DSA keys
  * Corrected a segfault when setting an empty gnutls_priority_t
    at gnutls_priority_set()
  * Added gnutls_x509_crt_get_subject_alt_name2()
  * The GPL version has been changed from version 2 to version 3.
    This affects the self-tests, command-line tools, the libgnutls-extra
    library, the relevant guile parts, and the build environment
- API and ABI modifications, library soname switch from 13 to 26
- change package structure:
  * branch off libgnutls-extra
    since this is now GPLv3 or later while libgnutls remains
    LGPLv2.1 or later
  * gnutls license change to GPLv3
- build without lzo support to avoid license problems
  since lzo is currently GPLv2 only
- removed merged patches:
  gnutls-fix_size_t.patch
* Tue Oct 23 2007 mkoenig@suse.de
- update to version 2.0.1
- change package layout to conform shlib policy:
  rename gnutls-devel -> libgnutls-devel
  new subpackage libgnutls13
- removed patches:
  gnutls-1.4.4-sign-callback.patch
  gnutls-1.6.1-compiler_warnings.patch
* Thu Aug 30 2007 mkoenig@suse.de
- fix srptool [#208227]
- fix some compiler warnings
* Fri Aug  3 2007 hvogel@suse.de
- Some additions for evolution smart card support
* Thu May 10 2007 mkoenig@suse.de
- Fix segfault on s390x [#97441]
  gnutls-fix_size_t.patch
* Tue Jan 23 2007 mkoenig@suse.de
- update to new stable branch 1.6.1:
  * Fix the list of trusted CAs that server's send to clients.
  * Fix gnutls_certificate_set_x509_crl to initialize the CRL
    before using it.
  * Encode UID fields in DN's as DirectoryString.
  * Fix ./configure failure with non-GCC compilers.
  * A GnuTLS C++ library is part of the official distribution.
  * New APIs for custom push/pull function error reporting.
* Tue Oct 24 2006 mkoenig@suse.de
- move developer related docs to devel package and remove
  binary stuff from docs [#212454]
* Tue Sep 19 2006 mkoenig@suse.de
- update to version 1.4.4:
  * bugfix release
  * fixes security vulnerability [#206636] (CVE-2006-4790)
* Thu Aug 31 2006 mkoenig@suse.de
- update to new stable branch 1.4.1:
  * The command line tools now use getaddrinfo and support IPv6.
  * gnutls-cli can now recognize services and port numbers with
    the -p option.
  * Error messages are now translated using GNU Gettext.
  * GnuTLS now support TLS Inner application (TLS/IA).
  * API and ABI modifications:
    + Support for DHE-PSK cipher suites has been added.
    + Removed the RIPEMD ciphersuites.
    + Remove GnuTLS 0.8.x compatibility functions.
    + Support for TLS Pre-Shared Key (TLS-PSK) ciphersuites have
    been added.
    + Certtool now generate keys in unencrypted PKCS#8 format for
    empty passwords.
    + Certtool now accept --password for --key-info and encrypted
    PKCS#8 keys.
    + gnutls_x509_privkey_import_pkcs8 now accept unencrypted
    PEM PKCS#8 keys,
    + New function to set a X.509 private key and certificate
    pairs, and/or CRLs, from an PKCS#12 file.
    + New APIs to acceess the client and server random fields in
    a session.
    + New APIs to access the TLS Pseudo-Random-Function (PRF).
    + New API to access the TLS master secret.
    + The function gnutls_x509_crt_to_xml now return an internal
    error.
  * Several bugfixes:
    + Corrected a bug in certtool for 64 bit machines.
    + Fix gnutls-cli STARTTLS hang when SIGINT is sent too quickly.
    + Fix crash in TLS resume code, caused by TLS/IA changes.
    + Corrected bugs in gnutls_certificate_set_x509_crl() and
    gnutls_certificate_set_x509_trust().
    + Fixed bug in non-blocking gnutls_bye().
    + Fix read of out bounds bug in DER parser.
    + Fixed bug in OpenPGP authentication handshake.
* Fri Feb 17 2006 ro@suse.de
- cleanup doc directory (.deps,.libs)
* Fri Feb 10 2006 hvogel@suse.de
- Update to version 1.2.10. This release fixes several serious
  bugs that would make the DER decoder in libtasn1 crash on
  invalid input [#149897]. Including:
  * Corrected a bug in certtool for 64 bit machines.
  * Fix gnutls-cli STARTTLS hang when SIGINT is sent too quickly
  * Corrected bugs in gnutls_certificate_set_x509_crl() and
    gnutls_certificate_set_x509_trust(), that caused memory
    corruption if more than one certificates were added.
  * Fixed bug in non-blocking gnutls_bye(). gnutls_record_send()
    will no longer invalidate a session if the underlying send
    fails, but it will prevent future writes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Dec 20 2005 ro@suse.de
- do not package /usr/share/info/dir
* Fri Dec  9 2005 hvogel@suse.de
- update to version 1.2.9
* Tue Oct 25 2005 hvogel@suse.de
- update to version 1.2.8
* Mon Aug 22 2005 hvogel@suse.de
- fix data type comparison [Bug #104617]
* Sun Jul  3 2005 hvogel@suse.de
- update to version 1.2.5
* Wed Jun 29 2005 hvogel@suse.de
- patch from mrueckert to use external lzo again
* Thu Jun 23 2005 hvogel@suse.de
- use %%install_info/%%install_info_delete
* Tue Jun  7 2005 hvogel@suse.de
- update to version 1.2.4
* Thu Jun  2 2005 ro@suse.de
- fix specfile (don't apply non-existant patch1)
* Thu Jun  2 2005 hvogel@suse.de
- use included minilzo
* Wed May 25 2005 hvogel@suse.de
- Update to version 1.2.3 (fixes gnutls DOS Bug #83481)
- Include defines.h before gnutls.h, to pull in config.h, to make
  sure memmem.h prototype memmem properly
* Sat Jan 29 2005 hvogel@suse.de
- Update to version 1.2.0
* Wed Jan 19 2005 hvogel@suse.de
- update to version 1.1.23
- get rid of prebuild html/ps docu again, the devel packages has
  man-pages now
* Mon Dec 13 2004 hvogel@suse.de
- update to version 1.0.23
- make build of postscript/html docu configureable
* Sat Oct 23 2004 hvogel@suse.de
- move config script to the devel package
* Thu Oct 14 2004 hvogel@suse.de
- Update to version 1.0.21
* Tue Sep 28 2004 hvogel@suse.de
- add doc subpackage with prebuild html/ps docu (Bug #44496)
* Mon Sep 27 2004 hvogel@suse.de
- fix ac-quotation patch to include libgnutls-extra.m4 (Bug #46035)
* Tue Aug 31 2004 kukuk@suse.de
- Update to version 1.0.20
* Mon Aug 30 2004 kukuk@suse.de
- Add libopencdk-devel to neededforbuild
* Thu Jul 15 2004 hvogel@suse.de
- add libgcrypt-devel and lipgpg-error-devel to nfb
* Wed May 19 2004 hvogel@suse.de
- update to version 1.0.13
* Fri May 14 2004 mmj@suse.de
- Add C++ compiler to build
- Don't remove buildroot when installing
* Mon Mar  1 2004 hvogel@suse.de
- update to version 1.0.8
* Tue Feb 17 2004 hvogel@suse.de
- update to version 1.0.6
- fix autoconf quotations
* Wed May 14 2003 schubi@suse.de
- initial; Sourcecode received from XIMIAN
